import unittest
import rundec

class Alphas(unittest.TestCase):
    def test_AlL2AlH(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mtop = 173.0

      top    = rundec.TriplenfMmu()
      bottom = rundec.TriplenfMmu()

      top.nf   = 6
      top.Mth  = 173.0
      top.muth = 173.0

      bottom.nf = 5
      bottom.Mth = 4.8
      bottom.muth = 4.8


      dec = rundec.TriplenfMmuArray(4)
      dec[0] = top

      loops = 5
      self.assertAlmostEqual(crd.AlL2AlH(asMZ,MZ,dec,800.,loops),0.090493107274928766401,delta=1e-5)

      dec[0] = top
      dec[1] = bottom
      self.assertAlmostEqual(crd.AlL2AlH(0.22,4.,dec,800.,loops),0.089296507041035146862,delta=1e-5)
    
    def test_AlH2AlL(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mtop = 173.0

      top    = rundec.TriplenfMmu()
      bottom = rundec.TriplenfMmu()

      top.nf   = 6
      top.Mth  = 173.0
      top.muth = 173.0

      bottom.nf = 5
      bottom.Mth = 4.8
      bottom.muth = 4.8

      dec = rundec.TriplenfMmuArray(4)
      dec[0] = top

      loops = 5
      self.assertAlmostEqual(crd.AlH2AlL(0.090,800,dec,MZ,loops),0.1170572315,delta=1e-5)

      dec[0] = top
      dec[1] = bottom
      self.assertAlmostEqual(crd.AlH2AlL(0.090,800,dec,4.0,loops),0.2245399988,delta=1e-5)

    def test_AlphasExact(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mbMS = 4.18
      
      nf = 5

      loops = 5
      self.assertAlmostEqual(crd.AlphasExact(asMZ, MZ, mbMS, nf, loops),0.224248705,delta=1e-5)

      loops = 4
      self.assertAlmostEqual(crd.AlphasExact(asMZ, MZ, mbMS, nf, loops),0.2242363603,delta=1e-5)

      loops = 3
      self.assertAlmostEqual(crd.AlphasExact(asMZ, MZ, mbMS, nf, loops),0.2239618329,delta=1e-5)

      loops = 2
      self.assertAlmostEqual(crd.AlphasExact(asMZ, MZ, mbMS, nf, loops),0.2232085998,delta=1e-5)

      loops = 1
      self.assertAlmostEqual(crd.AlphasExact(asMZ, MZ, mbMS, nf, loops),0.2118462908,delta=1e-5)

      loops = 5
      nf = 4
      self.assertAlmostEqual(crd.AlphasExact(asMZ, MZ, mbMS, nf, loops),0.2493330857,delta=1e-5)

      nf = 3
      self.assertAlmostEqual(crd.AlphasExact(asMZ, MZ, mbMS, nf, loops),0.2825081752,delta=1e-5)

    def test_AlphasLam(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mbMS = 4.18
      mtop = 173
      Lambda = 0.2074569921

      loops = 5
      nf = 5
      self.assertAlmostEqual(crd.AlphasLam(Lambda, MZ, nf, loops),0.1178938389,delta=1e-5)

      loops = 3
      nf = 3
      self.assertAlmostEqual(crd.AlphasLam(Lambda, MZ, nf, loops),0.09811687777,delta=1e-5) 

      loops = 5
      nf = 5
      self.assertAlmostEqual(crd.AlphasLam(Lambda, mtop, nf, loops),0.1075199029,delta=1e-5)


  

if __name__ == '__main__':
   unittest.main()


# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.0
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _rundec
else:
    import _rundec

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _rundec.delete_SwigPyIterator

    def value(self):
        return _rundec.SwigPyIterator_value(self)

    def incr(self, n=1):
        return _rundec.SwigPyIterator_incr(self, n)

    def decr(self, n=1):
        return _rundec.SwigPyIterator_decr(self, n)

    def distance(self, x):
        return _rundec.SwigPyIterator_distance(self, x)

    def equal(self, x):
        return _rundec.SwigPyIterator_equal(self, x)

    def copy(self):
        return _rundec.SwigPyIterator_copy(self)

    def next(self):
        return _rundec.SwigPyIterator_next(self)

    def __next__(self):
        return _rundec.SwigPyIterator___next__(self)

    def previous(self):
        return _rundec.SwigPyIterator_previous(self)

    def advance(self, n):
        return _rundec.SwigPyIterator_advance(self, n)

    def __eq__(self, x):
        return _rundec.SwigPyIterator___eq__(self, x)

    def __ne__(self, x):
        return _rundec.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n):
        return _rundec.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n):
        return _rundec.SwigPyIterator___isub__(self, n)

    def __add__(self, n):
        return _rundec.SwigPyIterator___add__(self, n)

    def __sub__(self, *args):
        return _rundec.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _rundec:
_rundec.SwigPyIterator_swigregister(SwigPyIterator)
class PairDouble(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _rundec.PairDouble_swiginit(self, _rundec.new_PairDouble(*args))
    first = property(_rundec.PairDouble_first_get, _rundec.PairDouble_first_set)
    second = property(_rundec.PairDouble_second_get, _rundec.PairDouble_second_set)
    def __len__(self):
        return 2
    def __repr__(self):
        return str((self.first, self.second))
    def __getitem__(self, index): 
        if not (index % 2):
            return self.first
        else:
            return self.second
    def __setitem__(self, index, val):
        if not (index % 2):
            self.first = val
        else:
            self.second = val
    __swig_destroy__ = _rundec.delete_PairDouble

# Register PairDouble in _rundec:
_rundec.PairDouble_swigregister(PairDouble)
class PairDoubleVector(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def iterator(self):
        return _rundec.PairDoubleVector_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self):
        return _rundec.PairDoubleVector___nonzero__(self)

    def __bool__(self):
        return _rundec.PairDoubleVector___bool__(self)

    def __len__(self):
        return _rundec.PairDoubleVector___len__(self)

    def __getslice__(self, i, j):
        return _rundec.PairDoubleVector___getslice__(self, i, j)

    def __setslice__(self, *args):
        return _rundec.PairDoubleVector___setslice__(self, *args)

    def __delslice__(self, i, j):
        return _rundec.PairDoubleVector___delslice__(self, i, j)

    def __delitem__(self, *args):
        return _rundec.PairDoubleVector___delitem__(self, *args)

    def __getitem__(self, *args):
        return _rundec.PairDoubleVector___getitem__(self, *args)

    def __setitem__(self, *args):
        return _rundec.PairDoubleVector___setitem__(self, *args)

    def pop(self):
        return _rundec.PairDoubleVector_pop(self)

    def append(self, x):
        return _rundec.PairDoubleVector_append(self, x)

    def empty(self):
        return _rundec.PairDoubleVector_empty(self)

    def size(self):
        return _rundec.PairDoubleVector_size(self)

    def swap(self, v):
        return _rundec.PairDoubleVector_swap(self, v)

    def begin(self):
        return _rundec.PairDoubleVector_begin(self)

    def end(self):
        return _rundec.PairDoubleVector_end(self)

    def rbegin(self):
        return _rundec.PairDoubleVector_rbegin(self)

    def rend(self):
        return _rundec.PairDoubleVector_rend(self)

    def clear(self):
        return _rundec.PairDoubleVector_clear(self)

    def get_allocator(self):
        return _rundec.PairDoubleVector_get_allocator(self)

    def pop_back(self):
        return _rundec.PairDoubleVector_pop_back(self)

    def erase(self, *args):
        return _rundec.PairDoubleVector_erase(self, *args)

    def __init__(self, *args):
        _rundec.PairDoubleVector_swiginit(self, _rundec.new_PairDoubleVector(*args))

    def push_back(self, x):
        return _rundec.PairDoubleVector_push_back(self, x)

    def front(self):
        return _rundec.PairDoubleVector_front(self)

    def back(self):
        return _rundec.PairDoubleVector_back(self)

    def assign(self, n, x):
        return _rundec.PairDoubleVector_assign(self, n, x)

    def resize(self, *args):
        return _rundec.PairDoubleVector_resize(self, *args)

    def insert(self, *args):
        return _rundec.PairDoubleVector_insert(self, *args)

    def reserve(self, n):
        return _rundec.PairDoubleVector_reserve(self, n)

    def capacity(self):
        return _rundec.PairDoubleVector_capacity(self)
    __swig_destroy__ = _rundec.delete_PairDoubleVector

# Register PairDoubleVector in _rundec:
_rundec.PairDoubleVector_swigregister(PairDoubleVector)
class TriplenfMmuArray(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, nelements):
        _rundec.TriplenfMmuArray_swiginit(self, _rundec.new_TriplenfMmuArray(nelements))
    __swig_destroy__ = _rundec.delete_TriplenfMmuArray

    def __getitem__(self, index):
        return _rundec.TriplenfMmuArray___getitem__(self, index)

    def __setitem__(self, index, value):
        return _rundec.TriplenfMmuArray___setitem__(self, index, value)

    def cast(self):
        return _rundec.TriplenfMmuArray_cast(self)

    @staticmethod
    def frompointer(t):
        return _rundec.TriplenfMmuArray_frompointer(t)

# Register TriplenfMmuArray in _rundec:
_rundec.TriplenfMmuArray_swigregister(TriplenfMmuArray)
class RunDecPairArray(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, nelements):
        _rundec.RunDecPairArray_swiginit(self, _rundec.new_RunDecPairArray(nelements))
    __swig_destroy__ = _rundec.delete_RunDecPairArray

    def __getitem__(self, index):
        return _rundec.RunDecPairArray___getitem__(self, index)

    def __setitem__(self, index, value):
        return _rundec.RunDecPairArray___setitem__(self, index, value)

    def cast(self):
        return _rundec.RunDecPairArray_cast(self)

    @staticmethod
    def frompointer(t):
        return _rundec.RunDecPairArray_frompointer(t)

# Register RunDecPairArray in _rundec:
_rundec.RunDecPairArray_swigregister(RunDecPairArray)
class RunDec_values(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    asMz = property(_rundec.RunDec_values_asMz_get, _rundec.RunDec_values_asMz_set)
    asMtau = property(_rundec.RunDec_values_asMtau_get, _rundec.RunDec_values_asMtau_set)
    Mz = property(_rundec.RunDec_values_Mz_get, _rundec.RunDec_values_Mz_set)
    Mh = property(_rundec.RunDec_values_Mh_get, _rundec.RunDec_values_Mh_set)
    muc = property(_rundec.RunDec_values_muc_get, _rundec.RunDec_values_muc_set)
    mc3 = property(_rundec.RunDec_values_mc3_get, _rundec.RunDec_values_mc3_set)
    mub = property(_rundec.RunDec_values_mub_get, _rundec.RunDec_values_mub_set)
    Mtau = property(_rundec.RunDec_values_Mtau_get, _rundec.RunDec_values_Mtau_set)
    Mc = property(_rundec.RunDec_values_Mc_get, _rundec.RunDec_values_Mc_set)
    Mb = property(_rundec.RunDec_values_Mb_get, _rundec.RunDec_values_Mb_set)
    Mt = property(_rundec.RunDec_values_Mt_get, _rundec.RunDec_values_Mt_set)

    def __init__(self):
        _rundec.RunDec_values_swiginit(self, _rundec.new_RunDec_values())
    __swig_destroy__ = _rundec.delete_RunDec_values

# Register RunDec_values in _rundec:
_rundec.RunDec_values_swigregister(RunDec_values)
class TriplenfMmu(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    nf = property(_rundec.TriplenfMmu_nf_get, _rundec.TriplenfMmu_nf_set)
    Mth = property(_rundec.TriplenfMmu_Mth_get, _rundec.TriplenfMmu_Mth_set)
    muth = property(_rundec.TriplenfMmu_muth_get, _rundec.TriplenfMmu_muth_set)

    def __init__(self):
        _rundec.TriplenfMmu_swiginit(self, _rundec.new_TriplenfMmu())
    __swig_destroy__ = _rundec.delete_TriplenfMmu

# Register TriplenfMmu in _rundec:
_rundec.TriplenfMmu_swigregister(TriplenfMmu)
cvar = _rundec.cvar

class RunDecPair(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    first = property(_rundec.RunDecPair_first_get, _rundec.RunDecPair_first_set)
    second = property(_rundec.RunDecPair_second_get, _rundec.RunDecPair_second_set)

    def __init__(self):
        _rundec.RunDecPair_swiginit(self, _rundec.new_RunDecPair())
    __swig_destroy__ = _rundec.delete_RunDecPair

# Register RunDecPair in _rundec:
_rundec.RunDecPair_swigregister(RunDecPair)
class AsmMS(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr
    Asexact = property(_rundec.AsmMS_Asexact_get, _rundec.AsmMS_Asexact_set)
    mMSexact = property(_rundec.AsmMS_mMSexact_get, _rundec.AsmMS_mMSexact_set)

    def __init__(self):
        _rundec.AsmMS_swiginit(self, _rundec.new_AsmMS())
    __swig_destroy__ = _rundec.delete_AsmMS

# Register AsmMS in _rundec:
_rundec.AsmMS_swigregister(AsmMS)
class CRunDec(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _rundec.CRunDec_swiginit(self, _rundec.new_CRunDec(*args))
    mq = property(_rundec.CRunDec_mq_get, _rundec.CRunDec_mq_set)
    nfMmu = property(_rundec.CRunDec_nfMmu_get, _rundec.CRunDec_nfMmu_set)
    AM = property(_rundec.CRunDec_AM_get, _rundec.CRunDec_AM_set)

    def GetNf(self):
        return _rundec.CRunDec_GetNf(self)

    def SetNf(self, nf):
        return _rundec.CRunDec_SetNf(self, nf)

    def DecLambdaUp(self, lam, massth, nl, nloops):
        return _rundec.CRunDec_DecLambdaUp(self, lam, massth, nl, nloops)

    def DecLambdaDown(self, lam, massth, nl, nloops):
        return _rundec.CRunDec_DecLambdaDown(self, lam, massth, nl, nloops)

    def AlL2AlH(self, asl, mu1, decpar, mu2, nloops):
        return _rundec.CRunDec_AlL2AlH(self, asl, mu1, decpar, mu2, nloops)

    def AlH2AlL(self, ash, mu1, decpar, mu2, nloops):
        return _rundec.CRunDec_AlH2AlL(self, ash, mu1, decpar, mu2, nloops)

    def mL2mH(self, mql, asl, mu1, decpar, mu2, nloops):
        return _rundec.CRunDec_mL2mH(self, mql, asl, mu1, decpar, mu2, nloops)

    def mH2mL(self, mqh, ash, mu1, decpar, mu2, nloops):
        return _rundec.CRunDec_mH2mL(self, mqh, ash, mu1, decpar, mu2, nloops)

    def mOS2mPS(self, mOS, mq, asmu, mu, muf, nl, nloops):
        return _rundec.CRunDec_mOS2mPS(self, mOS, mq, asmu, mu, muf, nl, nloops)

    def mMS2mPS(self, mMS, mq, asmu, mu, muf, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_mMS2mPS(self, mMS, mq, asmu, mu, muf, nl, nloops, fdelm)

    def mPS2mMS(self, mPS, mq, asmu, mu, muf, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_mPS2mMS(self, mPS, mq, asmu, mu, muf, nl, nloops, fdelm)

    def mPS2mSI(self, mPS, mq, _as, muf, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_mPS2mSI(self, mPS, mq, _as, muf, nl, nloops, fdelm)

    def mOS2m1S(self, mOS, mq, asmu, mu, nl, nloops):
        return _rundec.CRunDec_mOS2m1S(self, mOS, mq, asmu, mu, nl, nloops)

    def mMS2m1S(self, mMS, mq, asmu, mu, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_mMS2m1S(self, mMS, mq, asmu, mu, nl, nloops, fdelm)

    def m1S2mMS(self, m1S, mq, asmu, mu, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_m1S2mMS(self, m1S, mq, asmu, mu, nl, nloops, fdelm)

    def m1S2mSI(self, m1S, mq, _as, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_m1S2mSI(self, m1S, mq, _as, nl, nloops, fdelm)

    def mOS2mRS(self, *args):
        return _rundec.CRunDec_mOS2mRS(self, *args)

    def mMS2mRS(self, *args):
        return _rundec.CRunDec_mMS2mRS(self, *args)

    def mRS2mMS(self, *args):
        return _rundec.CRunDec_mRS2mMS(self, *args)

    def mRS2mSI(self, *args):
        return _rundec.CRunDec_mRS2mSI(self, *args)

    def mOS2mRSp(self, mOS, mq, asmu, mu, nuf, nl, nloops):
        return _rundec.CRunDec_mOS2mRSp(self, mOS, mq, asmu, mu, nuf, nl, nloops)

    def mMS2mRSp(self, mMS, mq, asmu, mu, nuf, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_mMS2mRSp(self, mMS, mq, asmu, mu, nuf, nl, nloops, fdelm)

    def mRSp2mMS(self, mRS, mq, asmu, mu, nuf, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_mRSp2mMS(self, mRS, mq, asmu, mu, nuf, nl, nloops, fdelm)

    def mRSp2mSI(self, mRS, mq, _as, nuf, nl, nloops, fdelm=1.0):
        return _rundec.CRunDec_mRSp2mSI(self, mRS, mq, _as, nuf, nl, nloops, fdelm)

    def LamExpl(self, *args):
        return _rundec.CRunDec_LamExpl(self, *args)

    def LamImpl(self, *args):
        return _rundec.CRunDec_LamImpl(self, *args)

    def AlphasLam(self, *args):
        return _rundec.CRunDec_AlphasLam(self, *args)

    def AlphasExact(self, *args):
        return _rundec.CRunDec_AlphasExact(self, *args)

    def mMS2mMS(self, *args):
        return _rundec.CRunDec_mMS2mMS(self, *args)

    def AsmMSrunexact(self, *args):
        return _rundec.CRunDec_AsmMSrunexact(self, *args)

    def DecAsDownOS(self, *args):
        return _rundec.CRunDec_DecAsDownOS(self, *args)

    def DecAsUpOS(self, *args):
        return _rundec.CRunDec_DecAsUpOS(self, *args)

    def DecAsDownMS(self, *args):
        return _rundec.CRunDec_DecAsDownMS(self, *args)

    def DecAsUpMS(self, *args):
        return _rundec.CRunDec_DecAsUpMS(self, *args)

    def DecAsDownSI(self, *args):
        return _rundec.CRunDec_DecAsDownSI(self, *args)

    def DecAsUpSI(self, *args):
        return _rundec.CRunDec_DecAsUpSI(self, *args)

    def DecMqUpOS(self, *args):
        return _rundec.CRunDec_DecMqUpOS(self, *args)

    def DecMqDownOS(self, *args):
        return _rundec.CRunDec_DecMqDownOS(self, *args)

    def DecMqUpMS(self, *args):
        return _rundec.CRunDec_DecMqUpMS(self, *args)

    def DecMqDownMS(self, *args):
        return _rundec.CRunDec_DecMqDownMS(self, *args)

    def DecMqUpSI(self, *args):
        return _rundec.CRunDec_DecMqUpSI(self, *args)

    def DecMqDownSI(self, *args):
        return _rundec.CRunDec_DecMqDownSI(self, *args)

    def mMS2mOS(self, *args):
        return _rundec.CRunDec_mMS2mOS(self, *args)

    def mOS2mMS(self, *args):
        return _rundec.CRunDec_mOS2mMS(self, *args)

    def mMS2mSI(self, *args):
        return _rundec.CRunDec_mMS2mSI(self, *args)

    def mRI2mMS(self, *args):
        return _rundec.CRunDec_mRI2mMS(self, *args)

    def mMS2mRGI(self, *args):
        return _rundec.CRunDec_mMS2mRGI(self, *args)

    def mRGI2mMS(self, *args):
        return _rundec.CRunDec_mRGI2mMS(self, *args)

    def mOS2mSI(self, *args):
        return _rundec.CRunDec_mOS2mSI(self, *args)

    def mOS2mMSrun(self, *args):
        return _rundec.CRunDec_mOS2mMSrun(self, *args)

    def mMS2mOSrun(self, *args):
        return _rundec.CRunDec_mMS2mOSrun(self, *args)

    def mMS2mRI(self, *args):
        return _rundec.CRunDec_mMS2mRI(self, *args)

    def mOS2mMSit(self, *args):
        return _rundec.CRunDec_mOS2mMSit(self, *args)

    def mMS2mRGImod(self, *args):
        return _rundec.CRunDec_mMS2mRGImod(self, *args)

    def mMS2mKIN(self, *args):
        return _rundec.CRunDec_mMS2mKIN(self, *args)

    def mKIN2mMS(self, *args):
        return _rundec.CRunDec_mKIN2mMS(self, *args)
    __swig_destroy__ = _rundec.delete_CRunDec

# Register CRunDec in _rundec:
_rundec.CRunDec_swigregister(CRunDec)

def fSetdydx(S, A, nl):
    return _rundec.fSetdydx(S, A, nl)

def fSetdydxa1(S, x, A):
    return _rundec.fSetdydxa1(S, x, A)

def fSetdydxM1(S, A, M):
    return _rundec.fSetdydxM1(S, A, M)

def fSetdydxa2(S, x, A):
    return _rundec.fSetdydxa2(S, x, A)

def fSetdydxM2(S, A, M):
    return _rundec.fSetdydxM2(S, A, M)

def fSetdydxa3(S, x, A):
    return _rundec.fSetdydxa3(S, x, A)

def fSetdydxM3(S, A, M):
    return _rundec.fSetdydxM3(S, A, M)

def fSetdydxa4(S, x, A):
    return _rundec.fSetdydxa4(S, x, A)

def fSetdydxM4(S, A, M):
    return _rundec.fSetdydxM4(S, A, M)

def fSetdydxa5(S, x, A):
    return _rundec.fSetdydxa5(S, x, A)

def fSetdydxM5(S, A, M):
    return _rundec.fSetdydxM5(S, A, M)





import unittest
import rundec

class masses(unittest.TestCase):
    def test_mMS2mOS(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mbMS = 4.18
      scale_mbMS = mbMS
      mcMS = rundec.RunDecPair()
      mq = rundec.RunDecPairArray(4)

      #Calculate alpha_s at mbMS

      as5 = crd.AlphasExact(asMZ, MZ, mbMS, 5, 5)

      #Calculate on-shell bottom quark mass from MS-bar bottom quark mass.
      #without charm mass effects

      loops = 4
      nf = 5
      self.assertAlmostEqual(crd.mMS2mOS(mbMS,None,as5,scale_mbMS,nf,loops),5.053056783,delta=1e-5)

      #with charm mass effects

      mcMS.first = 0.993
      mcMS.second = 3.0
      mq[0] = mcMS
      
      loops = 4
      self.assertAlmostEqual(crd.mMS2mOS(mbMS,mq,as5,scale_mbMS,nf,loops),5.075469604,delta=1e-5)

      loops = 3
      self.assertAlmostEqual(crd.mMS2mOS(mbMS,mq,as5,scale_mbMS,nf,loops),4.941379483,delta=1e-5)
            
      loops = 2
      self.assertAlmostEqual(crd.mMS2mOS(mbMS,mq,as5,scale_mbMS,nf,loops),4.782817403,delta=1e-5)

    def test_mOS2mMS(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mtop = 173.0
      scale_mtopMS = 163.0
      mbMS = rundec.RunDecPair()
      mcMS= rundec.RunDecPair()
      mq = rundec.RunDecPairArray(4)

      #Calculate MS mass of top quark mass from on-shell mass.
      #without bottom and charm mass effects

      top    = rundec.TriplenfMmu()

      top.nf   = 6
      top.Mth  = 173.0
      top.muth = 173.0

      dec = rundec.TriplenfMmuArray(4)
      dec[0] = top
      loops = 5
      
      as6 = crd.AlL2AlH(asMZ,MZ,dec,scale_mtopMS,loops)
 
      nf = 6
      loops = 4
      self.assertAlmostEqual(crd.mOS2mMS(mtop,None,as6,scale_mtopMS,nf,loops),163.2257536,delta=1e-5)

      #include bottom mass effects

      mbMS.first  = 4.18
      mbMS.second = 4.18
      mq[0] = mbMS
      self.assertAlmostEqual(crd.mOS2mMS(mtop,mq,as6,scale_mtopMS,nf,loops),163.2071241,delta=1e-5)      
                             
      #include bottom and charm effects
                             
      mcMS.first  = 0.993
      mcMS.second = 3.0
      mq[0] = mbMS
      mq[1] = mcMS

      self.assertAlmostEqual(crd.mOS2mMS(mtop,mq,as6,scale_mtopMS,nf,loops),163.2015983,delta=1e-5)


    def test_mThr2mMS(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mbMS = 4.18
      scale_mbMS = mbMS
      mcMS = 1.3
      scale_mcMS = 1.3

      #run down to 2*mbMS
      astmp = crd.AlphasExact(asMZ,MZ,2*mbMS,5,5)
      #decouple as5 -> as4
      astmp = crd.DecAsDownSI(astmp,mbMS,2*mbMS,4,5)
      #run down to 3 GeV
      astmp= crd.AlphasExact(astmp,2*mbMS,3.0,4,5)
      #decouple as4 -> as3
      as3 = crd.DecAsDownSI(astmp,mcMS,3.0,3,5)

      self.assertAlmostEqual(as3,0.2444637693,delta=1e-5)

      #convert PS mass to MS mass
      mcPS = 1.153
      scale_mpPS = 2.0
      self.assertAlmostEqual(crd.mPS2mMS(mcPS,None,as3,3.0,scale_mpPS,3,4),0.9862692441,delta=1e-5)
     
      #convert 1S mass to MS mass
      mc1S = 1.5145
      self.assertAlmostEqual(crd.m1S2mMS(mc1S,None,as3,3.0,3,4),0.9575677386,delta=1e-5)

      #convert RS mass to MS mass
      mcRS = 1.043
      self.assertAlmostEqual(crd.mRS2mMS(mcRS,None,as3,3.0,2.0,3,4),1.006783427,delta=1e-5)

      #convert RS' mass to MS mass
      mcRSp = 1.357
      self.assertAlmostEqual(crd.mRSp2mMS(mcRSp,None,as3,3.0,2.0,3,4),0.9661584143,delta=1e-5)

    def test_mMS2mThr(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mbMS = 4.18
      scale_mbMS = mbMS

      #run down to 2*mbMS
      astmp = crd.AlphasExact(asMZ,MZ,2*mbMS,5,5)
      #decouple as5 -> as4
      astmp= crd.DecAsDownSI(astmp,mbMS,2*mbMS,4,5)
      #run down to mbMS
      as4= crd.AlphasExact(astmp,2*mbMS,mbMS,4,5)

      #convert MS mass to PS mass
      self.assertAlmostEqual(crd.mMS2mPS(mbMS,None,as4,mbMS,2.0,4,4),4.498302237,delta=1e-5)
     
      #convert MS mass to 1S mass
      self.assertAlmostEqual(crd.mMS2m1S(mbMS,None,as4,mbMS,4,4),4.684559198,delta=1e-5)

      #convert MS mass to RS mass
      self.assertAlmostEqual(crd.mMS2mRS(mbMS,None,as4,mbMS,2.0,4,4),4.348011645,delta=1e-5)

      #convert MS mass to RS' mass
      self.assertAlmostEqual(crd.mMS2mRSp(mbMS,None,as4,mbMS,2.0,4,4),4.74021953,delta=1e-5)

    def test_mMS2mkin(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mbMS = 4.163
      scale_mbMS = mbMS
      mcMS = rundec.RunDecPair()
      mq = rundec.RunDecPairArray(4)

      #run down to 2*mbMS
      astmp = crd.AlphasExact(asMZ,MZ,2*mbMS,5,5)
      #decouple as5 -> as4
      astmp= crd.DecAsDownSI(astmp,mbMS,2*mbMS,4,5)
      #run down to mbMS
      as4= crd.AlphasExact(astmp,2*mbMS,mbMS,4,5)

      mcMS.first = 0.993
      mcMS.second = 3.0
      mq[0] = mcMS
      loops = 3
      muWC = 1.0
      #convert MS mass to kinetic mass, scheme A
      scheme=0
      self.assertAlmostEqual(crd.mMS2mKIN(mbMS,mcMS,as4,mbMS,muWC,loops,scheme),4.541932121,delta=1e-5)
      #convert MS mass to kinetic mass, scheme B
      scheme=1
      self.assertAlmostEqual(crd.mMS2mKIN(mbMS,mcMS,as4,mbMS,muWC,loops,scheme),4.525651485,delta=1e-5)  
      #convert MS mass to kinetic mass, scheme C
      scheme=2
      self.assertAlmostEqual(crd.mMS2mKIN(mbMS,mcMS,as4,mbMS,muWC,loops,scheme),4.547027037,delta=1e-5)
      #convert MS mass to kinetic mass, scheme D
      scheme=3
      self.assertAlmostEqual(crd.mMS2mKIN(mbMS,mcMS,as4,mbMS,muWC,loops,scheme),4.543448616,delta=1e-5) 

    def test_mkin2mMS(self):
      crd = rundec.CRunDec()
      asMZ = 0.1179
      MZ = 91.1876
      mbkin = 4.550
      mbMS = 4.163
      muWC = 1.0
      mcMS = rundec.RunDecPair()
      mq = rundec.RunDecPairArray(4)

      #run down to 2*mbMS
      astmp = crd.AlphasExact(asMZ,MZ,2*mbMS,5,5)
      #decouple as5 -> as4
      astmp= crd.DecAsDownSI(astmp,mbMS,2*mbMS,4,5)
      #run down to mbMS
      as4= crd.AlphasExact(astmp,2*mbMS,mbkin,4,5)

      #run as4 to 3.0 GeV
      astmp=crd.AlphasExact(astmp,2*mbMS,3.0,4,5)
      #decouple as4 -> as3
      astmp=crd.DecAsDownMS(astmp,0.993,3.0,3,5)
      #run as3 to mbkin
      as3=crd.AlphasExact(astmp,3.0,mbkin,3,5)

      mcMS.first = 0.993
      mcMS.second = 3.0
      mq[0] = mcMS
      loops = 3
      muWC = 1.0

      #convert kinetic mass to MS mass, scheme A
      scheme=0
      self.assertAlmostEqual(crd.mKIN2mMS(mbkin,mcMS,as3,mbkin,muWC,loops,scheme),4.134409357,delta=1e-5)

      #convert kinetic mass to MS mass, scheme B
      scheme=1
      self.assertAlmostEqual(crd.mKIN2mMS(mbkin,mcMS,as4,mbkin,muWC,loops,scheme),4.126363246,delta=1e-5)

      #convert kinetic mass to MS mass, scheme C
      scheme=2
      self.assertAlmostEqual(crd.mKIN2mMS(mbkin,mcMS,as4,mbkin,muWC,loops,scheme),4.106094652,delta=1e-5)

      #convert kinetic mass to MS mass, scheme D
      scheme=3
      self.assertAlmostEqual(crd.mKIN2mMS(mbkin,mcMS,as3,mbkin,muWC,loops,scheme),4.134150911,delta=1e-5)

if __name__ == '__main__':

   unittest.main()


from setuptools import setup, Extension

ext_mod = Extension("_rundec",
                    sources=["_rundec.cc", "CRunDec3/CRunDec.3.1.cpp"],
                    define_macros=[('Py_LIMITED_API', '0x030A0000')],
                    py_limited_api=True,
                    )

setup(name="rundec",
      version="0.7",
      author="David M. Straub",
      author_email="david.straub@hm.edu",
      url="https://github.com/DavidMStraub/rundec-python",
      description="A Python wrapper around the CRunDec package for the "
                  " running and decoupling of the strong coupling constant "
                  "and quark masses",
      long_description="""`CRunDec` is a C++ program developed by
      Florian Herren and Matthias Steinhauser. This Python package
      provides a thin wrapper around `CRunDec` generated with SWIG.""",
      license="MIT",
      py_modules=['rundec'],
      ext_modules=[ext_mod],
      extras_require={'testing': ['pytest']},
      )
